@@ -13,4 +13,5 @@ Date:    2020/06/24 11:35:00
 
 from .pretrained_word_embedding_loader import PretrainedWordEmbeddingLoader
 from .general_pretrained_word_embedding_loader import GeneralPretrainedWordEmbeddingLoader
-from .glove import GloveLoader
+from .glove_loader import GloveLoader
+from .sgns_loader import SGNSLoader
